@@ -507,6 +507,8 @@ def timelist_set_list(model, min_, max_, format_):
 
 def add_operators(widget):
     def key_press(editable, event):
+        if not editable.get_editable():
+            return False
         if event.keyval in OPERATORS:
             value = widget.props.value
             if value:
@@ -523,6 +525,10 @@ def add_operators(widget):
             return True
         return False
 
+    if isinstance(widget, DateTime):
+        for child in widget.get_children():
+            add_operators(child)
+        return widget
     if isinstance(widget, gtk.ComboBoxEntry):
         editable = widget.get_child()
     else:
@@ -567,8 +573,7 @@ if __name__ == '__main__':
     t.show()
     v.pack_start(t, False, False)
 
-    dt = DateTime()
-    [add_operators(c) for c in dt.get_children()]
+    dt = add_operators(DateTime())
     dt.show()
     v.pack_start(dt, False, False)
 
