@@ -100,8 +100,10 @@ class EditableTreeView(TreeView):
 
     def set_cursor(self, path, focus_column=None, start_editing=False):
         self.grab_focus()
-        if focus_column and (focus_column._type in ('boolean')):
-            start_editing = False
+        if focus_column:
+            widget = self.view.get_column_widget(focus_column)
+            if isinstance(widget.renderer, gtk.CellRendererToggle):
+                start_editing = False
         self.scroll_to_cell(path, focus_column, use_align=False)
         super(EditableTreeView, self).set_cursor(path, focus_column,
                 start_editing)
